
const Main = imports.ui.main;
const PanelMenu = imports.ui.panelMenu;
const Gtk = imports.gi.Gtk;
const Meta = imports.misc.extensionUtils.getCurrentExtension();
const St = imports.gi.St;
const Keymap = imports.gi.Gdk.Keymap.get_default();
const Lang = imports.lang;

let indicator;

function displayState(panel, numlock_state, capslock_state)
{
    if ((panel.actor.visible = (numlock_state | capslock_state)) == false)
        return;

    numlock_state ? panel.numIcon.show() : panel.numIcon.hide();
    capslock_state ? panel.capsIcon.show() : panel.capsIcon.hide();
}

const LockKeysIndicator = new Lang.Class
({
    Name: 'LockKeysIndicator',
    Extends: PanelMenu.Button,

    _init: function()
    {
        PanelMenu.Button.prototype._init.call(this, St.Align.START);

        // For highlight to work properly you have to use themed
        // icons. Fortunately we can add our directory to the search path.
        Gtk.IconTheme.get_default().append_search_path(Meta.dir.get_path());

        this.numIcon = new St.Icon({icon_name: "icon-numlock", style_class: 'system-status-icon'});
        this.capsIcon = new St.Icon({icon_name: "icon-capslock", style_class: 'system-status-icon'});

        this.layoutManager = new St.BoxLayout();
        this.layoutManager.add(this.numIcon);
        this.layoutManager.add(this.capsIcon);

        this.actor.add_actor(this.layoutManager);
    },

    setActive: function(enabled)
    {
        if (enabled)
        {
            this._keyboardStateChangedId = Keymap.connect('state-changed', Lang.bind(this, this._updateState));
            this._updateState();
        }
        else
            Keymap.disconnect(this._keyboardStateChangedId);
    },

    _updateState: function()
    {
        displayState(this, Keymap.get_num_lock_state(), Keymap.get_caps_lock_state());
    }
});

function enable()
{
    indicator = new LockKeysIndicator();
    Main.panel.addToStatusArea('lockkeys', indicator, 2);
    indicator.setActive(true);
}

function disable()
{
    indicator.setActive(false);
    indicator.destroy();
}
